@@ -10,6 +10,7 @@ import os
 sys.modules["ROOT_DIR"] = os.path.abspath(os.path.dirname(__file__))
 
 from .api import *
+from .aio_api import *
 from .client import testClient, auth
 from .client import __version__
 
@@ -21,4 +22,5 @@ __all__ = [
     "testClient",
     "__version__"
 ]
-__all__.extend(api.__all__)
\ No newline at end of file
+__all__.extend(api.__all__)
+__all__.extend(aio_api.__all__)
\ No newline at end of file
